Module capability

Module capability 

Capability definitions inside the Gateway context.

Structs

GatewayCapability
Simplified descriptor for a capability registered at the gateway.

Constants

GATEWAY_RUNTIME_CAPABILITY
Stable Runtime infrastructure capability implemented by the Gateway.

Functions

gateway_capability_descriptor
Builds the descriptor consumed by the Runtime capability policy when the Gateway deployment adapter is selected.