pub struct MeshPeerResponse {
pub schema: String,
pub request_id: String,
pub status_code: u16,
pub body: Vec<u8>,
pub error: Option<String>,
}Expand description
Logical Peer RPC HTTP response returned through the Gateway mesh relay.
Fields
schema: StringSchema marker. Must be MESH_HTTP_SCHEMA_V1.
request_id: StringStable request identity.
status_code: u16HTTP status code returned by the target peer host.
body: Vec<u8>Encoded response body returned by the target peer host.
error: Option<String>Controlled transport failure when the target worker could not complete the request.
Implementations
Sourceimpl MeshPeerResponse
impl MeshPeerResponse
Sourcepub fn ok(request_id: impl Into<String>, response: PeerRpcHttpResponse) -> Self
pub fn ok(request_id: impl Into<String>, response: PeerRpcHttpResponse) -> Self
Creates a successful logical HTTP response.
Sourcepub fn rejected(request_id: impl Into<String>, error: impl Into<String>) -> Self
pub fn rejected(request_id: impl Into<String>, error: impl Into<String>) -> Self
Creates a controlled relay failure.
Sourcepub fn into_peer_response(self) -> Result<PeerRpcHttpResponse, PeerRpcError>
pub fn into_peer_response(self) -> Result<PeerRpcHttpResponse, PeerRpcError>
Converts this relay response to a logical Peer RPC HTTP response.